# gem install oauth2
require 'oauth2'
require 'json'

module Friendlyscore

	class Friendlyscore

		attr_accessor :client_id, :client_secret, :base_url
		attr_reader :client

		def initialize(cid,sec)
			@by            = nil
			@id            = nil
			@client_id     = cid
			@client_secret = sec
            @base_url      = 'https://friendlyscore.com'
		end

		def connect
			@client = OAuth2::Client.new(
				@client_id,
				@client_secret,
				{
					:site      => @base_url,
					:token_url => '/oauth/v2/token'
				}
			)
		end

		def token
			connect if @client.nil?
			client.client_credentials.get_token
		end

		def users(page=1, max_results=20)
			token.get '/api/v2/users.json', :params => { 'page' => page, 'max_results' => max_results }
		end

		def by_id(id)
			@by = 'id'
			@id = id
			self
		end

		def by_partner_id(id)
			@by = 'partner-id'
			@id = id
			self
		end

		def calculate_score(params)
			token.post "/api/v2/users/#{@by}/#{@id}/calculate_score.json", :body => params
		end

		def user
			token.get "/api/v2/users/#{@by}/#{@id}/show.json"
		end

		def google_places_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/places.json"
		end

		def google_dob_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/days-of-birth.json"
		end
		
		def google_skills_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/skills.json"
		end
		
		def google_phones_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/phones.json"
		end
		
		def google_work_periods_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/work-periods.json"
		end
		
		def google_universities_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/universities.json"
		end

		def google_emails_data
			token.get "/api/v2/users/#{@by}/#{@id}/google/raw-file-data/emails.json"
		end

		def user_ip_address_data
			token.get "/api/v2/users/#{@by}/#{@id}/show/ip-address-data.json"
		end

		def user_min_fraud_data
			token.get "/api/v2/users/#{@by}/#{@id}/show/min-fraud-data.json"
		end

		def add_user_performance_data(params)
			token.post "/api/v2/users/#{@by}/#{@id}/performance-data.json", :body => params
		end

		def set_positive(val)
			token.put "/api/v2/users/#{@by}/#{@id}/positive/#{val ? '1' : '0'}.json"
		end

		def set_status(status, description)
			params = {
				'status'      => status,
				'description' => description
			}
			token.post "/api/v2/users/#{@by}/#{@id}/status.json", :body => params
		end

	end

end
